Water Balance
=========================

As the model already indicates (PCR-GLOB Water Balance), it's all about the water balance. 
While the water balance computations are not direct output of PCR-GLOBWB, their components can be retrieved from the log-file.

.. autoclass:: water_balance.water_balance
    :members:
